// SPDX-License-Identifier: Apache-2.0
// Copyright © 2022 Intel Corporation

#include "gen/gen.h"

int64_t add64(const int64_t, const int64_t);
